@@ -4,6 +4,9 @@ use std::fmt::Display;
 use std::fmt::Formatter;
 use std::fmt::Result;
 
+use crate::_Object;
+
+
 #[derive(Copy, Clone)]
 pub struct Char {
     _char: char
@@ -15,21 +18,21 @@ impl Char {
             _char
         }
     }
-
-    pub fn __repr__(&self) -> String {
-        format!("'{}'", self._char)
-    }
 }
 
-// impl _Object for Char {
-//     fn __str__(self) {
-//         prCharln!("{}", self._Chareger);
-//     }
+impl _Object for Char {
+    fn __str__(&self) -> String {
+        String::from(self._char)
+    }
 
-//     fn __len__(self) -> i32 {
-//         self._Chareger
-//     }
-// }
+    fn __repr__(&self) -> String {
+        format!("'{}'", self._char)
+    }
+
+    fn __len__(&self) -> usize {
+        8
+    }
+}
 
 impl Display for Char {
     fn fmt(&self, f: &mut Formatter<'_>) -> Result {
